@@ -13,11 +13,12 @@ import time
 # y_val = dic_clfs1['yl3']
 
 class CPEnv(Env):
-    print("正在搭建初始环境1.3")
+    print("正在搭建初始环境153")
     print("文件位置：", sys.argv[0])
-    dic_clfs1 = np.load('dic_clfs.npy', allow_pickle=True).item()
-    # dic_clfs1 = np.load('/content/drive/MyDrive/Colab Notebooks/dic_clfs.npy', allow_pickle=True).item()
-    print(dic_clfs1['xl2'].shape, dic_clfs1['yl2'].shape, dic_clfs1['xl3'].shape, dic_clfs1['yl3'].shape)
+    # dic_clfs1 = np.load('dic_clfs1.npy', allow_pickle=True).item()
+    dic_clfs1 = np.load('/content/drive/MyDrive/Colab Notebooks/dic_clfs1.npy', allow_pickle=True).item()
+    # print(dic_clfs1['xl2'].shape, dic_clfs1['yl2'].shape, dic_clfs1['xl3'].shape, dic_clfs1['yl3'].shape)
+    print(dic_clfs1['tx'].shape, dic_clfs1['ty'].shape)
 
     metadata = {'render.modes': ['human']}
 
@@ -27,8 +28,13 @@ class CPEnv(Env):
 
         # self.X_train = np.load('/content/drive/MyDrive/Colab Notebooks/dic_clfs.npy', allow_pickle=True).item()['xl2']
         # self.y_train = np.load('/content/drive/MyDrive/Colab Notebooks/dic_clfs.npy', allow_pickle=True).item()['yl2']
-        self.X_train = np.load('dic_clfs.npy', allow_pickle=True).item()['xl2']
-        self.y_train = np.load('dic_clfs.npy', allow_pickle=True).item()['yl2']
+
+        self.X_train = np.load('/content/drive/MyDrive/Colab Notebooks/dic_clfs1.npy', allow_pickle=True).item()['tx']
+        self.y_train = np.load('/content/drive/MyDrive/Colab Notebooks/dic_clfs1.npy', allow_pickle=True).item()['ty']
+
+        # self.X_train = np.load('dic_clfs1.npy', allow_pickle=True).item()['tx']
+        self.X_train = self.X_train.reshape(self.X_train.shape[0],self.X_train.shape[1])
+        # self.y_train = np.load('dic_clfs1.npy', allow_pickle=True).item()['ty']
 
         # print(self.X_train.shape)
         # self.X_val = np.load('dic_clfs.npy', allow_pickle=True).item()['xl3']
